@@ -43,7 +43,10 @@ class SourceCode:  # noqa: R090
     """Python source code entity."""
 
     def __init__(
-        self, source_code: str, config: Optional[Dict[str, Any]] = None
+        self,
+        source_code: str,
+        config: Optional[Dict[str, Any]] = None,
+        keep_unused_imports: bool = False,
     ) -> None:
         """Initialize the object."""
         self.header: List[str] = []
@@ -53,6 +56,7 @@ class SourceCode:  # noqa: R090
         self.config: Dict[str, Any] = config if config else {}
         self._trailing_newline = False
         self._split_code(source_code)
+        self.keep_unused_imports = keep_unused_imports
 
     def fix(self) -> str:
         """Fix python source code to correct import statements.
@@ -303,7 +307,7 @@ class SourceCode:  # noqa: R090
                 if object_name not in fixed_packages:
                     self._add_package(object_name)
                     fixed_packages.append(object_name)
-            elif isinstance(message, UnusedImport):
+            elif isinstance(message, UnusedImport) and not self.keep_unused_imports:
                 import_name = message.message_args[0]
                 self._remove_unused_imports(import_name)
 
@@ -541,17 +545,17 @@ def extract_package_objects(name: str) -> Dict[str, str]:
                     # Try to load the object from the module instead of the
                     # submodules.
                     if hasattr(module, "__all__") and object_name in module.__all__:
-                        package_objects[
-                            object_name
-                        ] = f"from {module.__name__} import {object_name}"
+                        package_objects[object_name] = (
+                            f"from {module.__name__} import {object_name}"
+                        )
                     else:
-                        package_objects[
-                            object_name
-                        ] = f"from {package_object.__module__} import {object_name}"
+                        package_objects[object_name] = (
+                            f"from {package_object.__module__} import {object_name}"
+                        )
 
             elif not re.match(r"^_.*", object_name):
                 # The rest of objects
-                package_objects[
-                    object_name
-                ] = f"from {module.__name__} import {object_name}"
+                package_objects[object_name] = (
+                    f"from {module.__name__} import {object_name}"
+                )
     return package_objects
